==> haskell-system-fileio-0.3.16.4-209-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-system-fileio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 system-fileio
version:              0.3.16.4
visibility:           public
id:                   system-fileio-0.3.16.4-39g0fih4TSuLIJ8giSudxQ
key:                  system-fileio-0.3.16.4-39g0fih4TSuLIJ8giSudxQ
license:              MIT
maintainer:           FP Complete <michael@fpcomplete.com>
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://github.com/fpco/haskell-filesystem
synopsis:
    Consistent filesystem interaction across GHC versions (deprecated)

description:
    Please see: https://plus.google.com/+MichaelSnoyman/posts/Ft5hnPqpgEx

category:             System
abi:                  4c4ea5337c570aa430e98e5beb14cf0e
exposed:              True
exposed-modules:      Filesystem
import-dirs:          /usr/lib/ghc-9.0.2/site-local/system-fileio-0.3.16.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/system-fileio-0.3.16.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-system-fileio
hs-libraries:         HSsystem-fileio-0.3.16.4-39g0fih4TSuLIJ8giSudxQ
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    system-filepath-0.4.14-GK5ruxmjn0w7DfEOVa7EyC text-1.2.5.0
    time-1.9.3 unix-2.7.2.2

haddock-interfaces:
    /usr/share/doc/haskell-system-fileio/html/system-fileio.haddock

haddock-html:         /usr/share/doc/haskell-system-fileio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-system-fileio-0.3.16.4-224-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-system-fileio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 system-fileio
version:              0.3.16.4
visibility:           public
id:                   system-fileio-0.3.16.4-6kqEIraUBpcAz3SECr3sBV
key:                  system-fileio-0.3.16.4-6kqEIraUBpcAz3SECr3sBV
license:              MIT
maintainer:           FP Complete <michael@fpcomplete.com>
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://github.com/fpco/haskell-filesystem
synopsis:
    Consistent filesystem interaction across GHC versions (deprecated)

description:
    Please see: https://plus.google.com/+MichaelSnoyman/posts/Ft5hnPqpgEx

category:             System
abi:                  caf79c3ede6f6b2d578eacb3450b8dd2
exposed:              True
exposed-modules:      Filesystem
import-dirs:          /usr/lib/ghc-9.0.2/site-local/system-fileio-0.3.16.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/system-fileio-0.3.16.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-system-fileio
hs-libraries:         HSsystem-fileio-0.3.16.4-6kqEIraUBpcAz3SECr3sBV
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    system-filepath-0.4.14-GHKDuWJRe2MAtGU4oy46w4 text-1.2.5.0
    time-1.9.3 unix-2.7.2.2

haddock-interfaces:
    /usr/share/doc/haskell-system-fileio/html/system-fileio.haddock

haddock-html:         /usr/share/doc/haskell-system-fileio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
